==> haskell-mmark-0.0.7.6-169.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mmark
version:              0.0.7.6
visibility:           public
id:                   mmark-0.0.7.6-Gd5SeFmZKhhDH7CgtikiE9
key:                  mmark-0.0.7.6-Gd5SeFmZKhhDH7CgtikiE9
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mmark-md/mmark
synopsis:             Strict markdown processor for writers
description:          Strict markdown processor for writers.
category:             Text
abi:                  02cdfa3c5b634594eabadf185e8a0206
exposed:              True
exposed-modules:      Text.MMark Text.MMark.Extension
hidden-modules:
    Text.MMark.Parser Text.MMark.Parser.Internal
    Text.MMark.Parser.Internal.Type Text.MMark.Render Text.MMark.Trans
    Text.MMark.Type Text.MMark.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/mmark-0.0.7.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mmark-0.0.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmark
hs-libraries:         HSmmark-0.0.7.6-Gd5SeFmZKhhDH7CgtikiE9
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV base-4.16.4.0
    case-insensitive-1.2.1.0-2Tjf2PFkxP43DkqVUMYCmf containers-0.6.5.1
    deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O
    email-validate-2.3.2.20-7OiNszYGMY4692br1eGoTm
    foldl-1.4.16-4cRhtlQkvFM7jJ2xSq3g8A
    hashable-1.4.3.0-7566tBsT9J8EFScR3Tb2Bc
    html-entity-map-0.1.0.0-4ulBq4KDgiqLr2SO7bidDI
    lucid-2.11.20230408-4lTvUuAHGJQ7LKqFnj5uvW
    megaparsec-9.5.0-Bj42S1sxqz5CEZGEYlrAL4
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-th-0.4.3.14-N8oH2Lt1wGBzxrEjsZjaw
    modern-uri-0.3.6.1-E4zhj7bjqwJ6C0ZHPkXjbb mtl-2.2.2
    parser-combinators-1.3.0-G0J7GFw9FY9Cgw8HeD2oK5 text-1.2.5.0
    text-metrics-0.3.2-7mX2nTvyv7PDS3xXMpPNAr
    unordered-containers-0.2.20-Kaqz4YtssULDpEsD0of7Qa
    yaml-0.11.11.2-DOjbEtSKr8VFK7XngTn0Mf

haddock-interfaces:   /usr/share/doc/haskell-mmark/html/mmark.haddock
haddock-html:         /usr/share/doc/haskell-mmark/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mmark-0.0.7.6-170-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mmark
version:              0.0.7.6
visibility:           public
id:                   mmark-0.0.7.6-6g2VDBC9Ei8JJXAgYRqiiF
key:                  mmark-0.0.7.6-6g2VDBC9Ei8JJXAgYRqiiF
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mmark-md/mmark
synopsis:             Strict markdown processor for writers
description:          Strict markdown processor for writers.
category:             Text
abi:                  3e12b16d471886b22f7d4fc3fc6babf0
exposed:              True
exposed-modules:      Text.MMark Text.MMark.Extension
hidden-modules:
    Text.MMark.Parser Text.MMark.Parser.Internal
    Text.MMark.Parser.Internal.Type Text.MMark.Render Text.MMark.Trans
    Text.MMark.Type Text.MMark.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/mmark-0.0.7.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mmark-0.0.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmark
hs-libraries:         HSmmark-0.0.7.6-6g2VDBC9Ei8JJXAgYRqiiF
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8 base-4.16.4.0
    case-insensitive-1.2.1.0-BBCkGXkqh3nGRz3m4HFNUT containers-0.6.5.1
    deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O
    email-validate-2.3.2.20-IrvwwkoZTbBIyrWIX9qX3v
    foldl-1.4.16-F6aCYvXCrBptEdT4ZqrtB
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    html-entity-map-0.1.0.0-7leywESE3yDL0GC1vXXVkP
    lucid-2.11.20230408-FdmLCBxTfAzG58zdz3Z55x
    megaparsec-9.5.0-Jwu5LIKr9Z8JTb6Qjv9hi0
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-th-0.4.3.14-N8oH2Lt1wGBzxrEjsZjaw
    modern-uri-0.3.6.1-1Aa3r4mu7TM2ZsYwi5BE5A mtl-2.2.2
    parser-combinators-1.3.0-G0J7GFw9FY9Cgw8HeD2oK5 text-1.2.5.0
    text-metrics-0.3.2-7fpEp4dNcrnG7aAG1Y3rWZ
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    yaml-0.11.11.2-3sWHAw2GBnQ38IoWLlyh5J

haddock-interfaces:   /usr/share/doc/haskell-mmark/html/mmark.haddock
haddock-html:         /usr/share/doc/haskell-mmark/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
